@@ -1,7 +1,7 @@
 
 ##  vdigest -- Vectorist digest functions for R
 ##
-##  Copyright (C) 2019         Matthew de Queljoe and Dirk Eddelbuettel
+##  Copyright (C) 2019 - 2025  Matthew de Queljoe and Dirk Eddelbuettel
 ##
 ##  This file is part of digest.
 ##
@@ -20,15 +20,16 @@
 
 getVDigest <- function(algo = c("md5", "sha1", "crc32", "sha256", "sha512",
                                 "xxhash32", "xxhash64", "murmur32", "spookyhash",
-                                "blake3", "crc32c"),
+                                "blake3", "crc32c", "xxh3_64", "xxh3_128"),
                         errormode=c("stop","warn","silent")){
     algo <- match.arg(algo, c("md5", "sha1", "crc32", "sha256", "sha512",
                               "xxhash32", "xxhash64", "murmur32", "spookyhash",
-                              "blake3", "crc32c"))
-    errormode <- match.arg(errormode, c("stop","warn","silent"))
+                              "blake3", "crc32c", "xxh3_64", "xxh3_128"))
+
     algoint <- algo_int(algo)
     non_streaming_algos <- c("md5", "sha1", "crc32", "sha256", "sha512",
-                             "xxhash32", "xxhash64", "murmur32", "blake3", "crc32c")
+                             "xxhash32", "xxhash64", "murmur32", "blake3",
+                             "crc32c", "xxh3_64", "xxh3_128")
     if (algo %in% non_streaming_algos)
         return(non_streaming_digest(algo, errormode, algoint))
     streaming_digest(algo, errormode, algoint)
@@ -84,7 +85,7 @@ non_streaming_digest <- function(algo, errormode, algoint){
         if (file) {
             algoint <- algoint+100
             object <- path.expand(object)
-            if (.isWindows()) object <- enc2utf8(object)
+            if (.isWindows()) object <- enc2utf8(object)                                        # #nocov
             check_file(object, errormode)
         }
         ## if skip is auto (or any other text for that matter), we just turn it
